## Bootcamp Geração Tech Unimed-BH - Ciência de Dados



## Links Úteis

[Site da Dio](https://dio.me/)

[Sintaxe Básica Markdown](https://www.markdownguide.org/basic-syntax/)

[Download do git](https://git-scm.com/downloads)

[Registrar no Pypi](https://pypi.org/account/register/)

[Registrar no Test Pypi]([https://test.pypi.org/account/register]))





https://pypi.org/account/register/



## Tecnologias utilizadas nos projetos

<div style="display: inline_block">
<img align="center" alt="git" height="70" width="60" src="https://cdn.jsdelivr.net/gh/devicons/devicon/icons/git/git-original-wordmark.svg"/>
<img align="center" alt="GitHub" height="70" width="60" src="https://cdn.jsdelivr.net/gh/devicons/devicon/icons/github/github-original-wordmark.svg" />
<img  align="center" alt="Python" height="70" width="60" src="https://cdn.jsdelivr.net/gh/devicons/devicon/icons/python/python-original-wordmark.svg" />              
</div>


## Desafio criação de pacote no pypi



```
Objetivo: 

Neste projeto aprenderemos a criar um pacote de exemplo de um jogo da velha em Python e disponibilizá-lo no repositório Pypi.
```

